package net.knarcraft.bookswithoutborders.command;

import net.knarcraft.bookswithoutborders.BooksWithoutBorders;
import net.knarcraft.bookswithoutborders.utility.InventoryHelper;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.bukkit.command.TabExecutor;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.BookMeta;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;

/**
 * Command executor for the clear command
 */
public class CommandClear implements TabExecutor {

    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label,
                             @NotNull String[] args) {
        if (!(sender instanceof Player player)) {
            BooksWithoutBorders.sendErrorMessage(sender, "This command can only be used by a player!");
            return false;
        }

        if (InventoryHelper.notHoldingOneWritableBookCheck(player, "You must be holding a writable book to " +
                "clear it!", "You cannot clear two books at once!")) {
            return false;
        }

        //Clear the player's held book
        ItemStack heldBook = InventoryHelper.getHeldBook(player, false);
        BookMeta bookMeta = (BookMeta) heldBook.getItemMeta();
        if (bookMeta == null) {
            BooksWithoutBorders.sendErrorMessage(sender, "Unable to get metadata for the held book!");
            return false;
        }
        bookMeta.setPages("");
        bookMeta.setAuthor(null);
        bookMeta.setGeneration(null);
        bookMeta.setTitle(null);
        heldBook.setItemMeta(bookMeta);
        BooksWithoutBorders.sendSuccessMessage(sender, "Book cleared!");
        return true;
    }

    @Nullable
    @Override
    public List<String> onTabComplete(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label,
                                      @NotNull String[] args) {
        return new ArrayList<>();
    }

}
