package net.knarcraft.bookswithoutborders.command;

import net.knarcraft.bookswithoutborders.BooksWithoutBorders;
import net.knarcraft.bookswithoutborders.utility.InventoryHelper;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.bukkit.command.TabExecutor;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.BookMeta;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;

/**
 * Command executor for the set generation command
 */
public class CommandSetGeneration implements TabExecutor {

    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label,
                             @NotNull String[] args) {
        if (!(sender instanceof Player player)) {
            BooksWithoutBorders.sendErrorMessage(sender, "This command can only be used by a player!");
            return false;
        }

        if (InventoryHelper.notHoldingOneWrittenBookCheck(player, "You must be holding a written book to" +
                " change its generation!", "You cannot change the generation of two books at once!")) {
            return false;
        }

        if (args.length < 1) {
            BooksWithoutBorders.sendErrorMessage(player, "You must specify the new generation for your book!");
            return false;
        }

        BookMeta.Generation generation;
        try {
            generation = BookMeta.Generation.valueOf(args[0]);
        } catch (IllegalArgumentException exception) {
            BooksWithoutBorders.sendErrorMessage(player, "Invalid book generation specified!");
            return false;
        }

        ItemStack heldBook = InventoryHelper.getHeldBook(player, true);
        BookMeta bookMeta = (BookMeta) heldBook.getItemMeta();
        if (bookMeta != null) {
            bookMeta.setGeneration(generation);
            heldBook.setItemMeta(bookMeta);
            return true;
        } else {
            BooksWithoutBorders.sendErrorMessage(player, "Unable to get book metadata!");
            return false;
        }
    }

    @Nullable
    @Override
    public List<String> onTabComplete(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label,
                                      @NotNull String[] args) {
        if (args.length == 1) {
            List<String> generations = new ArrayList<>();
            for (BookMeta.Generation generation : BookMeta.Generation.values()) {
                generations.add(generation.name());
            }
            return generations;
        }
        return new ArrayList<>();
    }

}
